@@ -1,19 +1,34 @@
 import itertools
 import json
+import platform
 from decimal import Decimal
 
-import ijson
+from ocdsmerge.util import get_tags
 
-from ocdskit.exceptions import UnknownFormatError
+from ocdskit.exceptions import UnknownFormatError, UnknownVersionError
+
+if platform.python_implementation() == 'PyPy':
+    import importlib
+
+    # yajl_c causes C errors. https://github.com/open-contracting/ocdskit/issues/178
+    # See ijson/__init__.py::_default_backend
+    for backend in ('yajl2_cffi', 'yajl2', 'yajl', 'python'):
+        try:
+            ijson = importlib.import_module(f'ijson.backends.{backend}')
+            break
+        except ImportError:
+            pass
+    else:
+        raise ImportError('no ijson backends available')
+else:
+    import ijson
 
 try:
     import orjson
 
     jsonlib = orjson
-    USING_ORJSON = True
 except ImportError:
     jsonlib = json
-    USING_ORJSON = False
 
 
 # See `grouper` recipe: https://docs.python.org/3.8/library/itertools.html#recipes
@@ -25,12 +40,11 @@ def grouper(iterable, n, fillvalue=None):
 # https://stackoverflow.com/questions/21663800/python-make-a-list-generator-json-serializable/46841935#46841935
 class SerializableGenerator(list):
     def __init__(self, iterable):
-        iterator = iter(iterable)
         try:
             # If `iter()` is omitted, then `__iter__` won't exhaust `head`.
-            self.head = iter([next(iterator)])
+            self.head = iter([next(iterable)])
             # Adding an item to the list ensures `__bool__` and `__len__` work.
-            self.append(iterator)
+            self.append(iterable)
         except StopIteration:
             # `__iter__` requires `head` to be set.
             self.head = []
@@ -46,11 +60,11 @@ class JSONEncoder(json.JSONEncoder):
             return float(obj)
         # https://docs.python.org/3/library/json.html#json.JSONEncoder.default
         try:
-            iter(obj)
+            iterable = iter(obj)
         except TypeError:
             pass
         else:
-            return SerializableGenerator(obj)
+            return SerializableGenerator(iterable)
         return json.JSONEncoder.default(self, obj)
 
 
@@ -77,7 +91,7 @@ def json_dumps(data, ensure_ascii=False, indent=None, sort_keys=False, **kwargs)
     Dumps JSON to a string, and returns it.
     """
     # orjson doesn't support `ensure_ascii` if `True`, `indent` if not `2` or other arguments except for `sort_keys`.
-    if not USING_ORJSON or ensure_ascii or indent and indent != 2 or kwargs:
+    if jsonlib == json or ensure_ascii or indent and indent != 2 or kwargs:
         if not indent:
             kwargs['separators'] = (',', ':')
         return json.dumps(data, cls=JSONEncoder, ensure_ascii=ensure_ascii, indent=indent, sort_keys=sort_keys,
@@ -111,6 +125,19 @@ def get_ocds_minor_version(data):
     return '1.0'
 
 
+def get_ocds_patch_tag(version):
+    """
+    Returns the OCDS patch version as a git tag (like ``1__1__4``) for a given minor version (like ``1.1``).
+
+    :raises UnknownVersionError: if the OCDS version is not recognized
+    """
+    prefix = version.replace('.', '__') + '__'
+    try:
+        return next(tag for tag in reversed(get_tags()) if tag.startswith(prefix))
+    except StopIteration:
+        raise UnknownVersionError(version)
+
+
 def is_package(data):
     """
     Returns whether the data is a record package or release package.
@@ -173,22 +200,7 @@ def is_linked_release(data):
     return 'url' in data and len(data) <= 3
 
 
-def _empty_package(uri, publisher, published_date, version):
-    if publisher is None:
-        publisher = {}
-
-    return {
-        'uri': uri,
-        'publisher': publisher,
-        'publishedDate': published_date,
-        'license': None,
-        'publicationPolicy': None,
-        'version': version,
-        'extensions': {},
-    }
-
-
-def detect_format(path, root_path=''):
+def detect_format(path, root_path='', reader=open):
     """
     Returns the format of OCDS data, and whether the OCDS data is concatenated or in an array.
 
@@ -200,7 +212,7 @@ def detect_format(path, root_path=''):
     :rtype: tuple
     :raises UnknownFormatError: if the format cannot be detected
     """
-    with open(path, 'rb') as f:
+    with reader(path, 'rb') as f:
         events = iter(ijson.parse(f, multiple_values=True))
 
         while True:
@@ -214,12 +226,12 @@ def detect_format(path, root_path=''):
         if event == 'start_array':
             prefix += 'item.'
         elif event != 'start_map':
-            raise UnknownFormatError('top-level JSON value is a {}'.format(event))
+            raise UnknownFormatError(f'top-level JSON value is a {event}')
 
-        records_prefix = '{}records'.format(prefix)
-        releases_prefix = '{}releases'.format(prefix)
-        ocid_prefix = '{}ocid'.format(prefix)
-        tag_item_prefix = '{}tag.item'.format(prefix)
+        records_prefix = f'{prefix}records'
+        releases_prefix = f'{prefix}releases'
+        ocid_prefix = f'{prefix}ocid'
+        tag_item_prefix = f'{prefix}tag.item'
 
         has_records = False
         has_releases = False
@@ -263,7 +275,7 @@ def _detect_format_result(is_concatenated, is_array, has_records, has_releases,
             infix = 'array'
         else:
             infix = 'object'
-        raise UnknownFormatError('top-level JSON value is a non-OCDS {}'.format(infix))
+        raise UnknownFormatError(f'top-level JSON value is a non-OCDS {infix}')
 
     return (detected_format, is_concatenated, is_array)
 
@@ -281,6 +293,21 @@ def _empty_release_package(uri='', publisher=None, published_date='', version=No
     return package
 
 
+def _empty_package(uri, publisher, published_date, version):
+    if publisher is None:
+        publisher = {}
+
+    return {
+        'uri': uri,
+        'publisher': publisher,
+        'publishedDate': published_date,
+        'license': None,
+        'publicationPolicy': None,
+        'version': version,
+        'extensions': {},
+    }
+
+
 def _update_package_metadata(output, package):
     for field in ('publisher', 'license', 'publicationPolicy'):
         if field in package:
