@@ -11,7 +11,7 @@ logger.setLevel(logging.WARNING)
 
 @pytest.fixture()
 def vcr_cassette_name(request):
-    return '{}-{}'.format(os.path.splitext(os.path.basename(request.node.fspath))[0], request.node.name)
+    return f'{os.path.splitext(os.path.basename(request.node.fspath))[0]}-{request.node.name}'
 
 
 @pytest.fixture(params=[True, False])
